#include "msp430.h"
#include "stdio.h"
#include "lib/radio_drv/radio_drv.h"
#include "lib/radio_drv/cc1x_utils.h"
#include "lib/radio_drv/hal_spi_rf.h"
#include "lib/uart_drv/uart_drv.h"
#include "LaunchPad_trx_demo.h"

/******************************************************************************
 * LOCAL FUNCTIONS
 */
extern void msp_setup(void);
extern unsigned long volatile time_counter;

/******************************************************************************
 * GLOBALS
 */
char u_str[UART_BUFF_SIZE];
unsigned char txBuffer[TX_BUFF_SIZE];
char user_button_pushed;
unsigned char wakeup_on_wdt;
trx_cfg_struct trx_cfg;


/******************************************************************************
 * @fn         main
 *
 * @brief      Main GUI application level control loop is implemented in the
 *             main loop. It is a state machine that cycles thru various states
 *             during the interactive use by the operator. The presents a text
 *             based GUI, the user is then promted to type in a command with
 *             a given set of parameters. The state machine then calls a simpler
 *             parser that tries to figure out what the user wants to do.
 *
 * input parameters
 *
 * @param       void
 *
 * output parameters
 *
 * @return      void
 *
 */
enum state_names {IDLE_RESET, WAIT, OPERATE};
void main (void)
{

	char idle_counter = 0;
	unsigned char u_str_length;
  enum state_names state = WAIT;

	/*  Stop WDT */
	WDTCTL = WDTPW + WDTHOLD;

	/* Setup MSP specific functions, IO's, timers and WDT */
  //Comes from lib/hal_mcu/hal_mcu.c
	msp_setup();

	/* Initialize the UART port */
	//hal_uart_init();

	/* enable uart echo function */
	//uart_drv_toggle_echo();

	/* initialize the radio subsystem */
	//trx_cfg.bit_rate = radio_init(1);
	//trx_cfg.bit_rate = trx_cfg.bit_rate * 100;

	// Perform initial setup of the CC radio
	//trx_cfg.b_length = TX_BUFF_SIZE;
	//rf_default_setup(&trx_cfg);

	/* Configure LED ports */
  // Defined in hal_spi_rf_exp430fr5994
	LED1_PxDIR |= LED1_PIN;
	LED2_PxDIR |= LED2_PIN;
	LED3_PxDIR |= LED3_PIN;
	LED4_PxDIR |= LED4_PIN;

	/* default all LEDs to off */
	HAL_LED1_OFF();
	HAL_LED2_OFF();
	HAL_LED3_OFF();
	HAL_LED4_OFF();

	/* Generally we use the WDT time wake the statemachine */
	wakeup_on_wdt = 1;

	/* indicator that button has been pressed */
	user_button_pushed = 0;

	/* Infinite loop with a 1 second timer */
	while(1)
	{

		/* Put MCU in low power mode, wait for UART and blink LED */
		HAL_LED2_OFF();
		_BIS_SR(LPM0_bits + GIE);
		HAL_LED2_ON();
		idle_counter++;


		/*
		 *    Main loop of state machine
		 */
		switch(state)
		{
		/* print the main menu to the UART buffer */
		case WAIT:
      if(idle_counter>250){
        state = IDLE_RESET;
      }
			state = OPERATE;
      break;
    case OPERATE:
      state = OPERATE;
      break;
		default:
			state = WAIT;
			break;
		}
	}
}
